(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('jb-switch')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', 'jb-switch'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.JBSwitch = {}, global.React));
})(this, (function (exports, React) { 'use strict';

  function useEvent(dom, event, handler, passive = false) {
      React.useEffect(() => {
          if (dom) {
              // initiate the event handler
              dom.addEventListener(event, handler, passive);
          }
          // this will clean up the event every time the component is re-rendered
          return function cleanup() {
              if (dom) {
                  dom.removeEventListener(event, handler, passive);
              }
          };
      });
  }

  const JBSwitch = React.forwardRef((props, ref) => {
      const element = React.useRef(null);
      const [refChangeCount, refChangeCountSetter] = React.useState(0);
      React.useImperativeHandle(ref, () => (element ? element.current : {}), [element]);
      React.useEffect(() => {
          refChangeCountSetter(refChangeCount + 1);
      }, [element.current]);
      const onchange = React.useCallback((e) => {
          if (props.value !== undefined && props.value !== null) {
              e.preventDefault();
          }
          if (typeof props.onChange == "function") {
              props.onChange(e);
          }
      }, [props.onChange, props.value]);
      useEvent(element.current, 'before-change', onchange, true);
      // useEvent(element.current, 'change', onchange, true);
      React.useEffect(() => {
          if (element.current && props.isLoading !== undefined && props.isLoading !== null && typeof props.isLoading == "boolean") {
              element.current.isLoading = props.isLoading;
          }
      }, [props.isLoading]);
      React.useEffect(() => {
          if (element.current && props.value !== null && props.value !== undefined) {
              element.current.value = props.value;
          }
      }, [props.value]);
      React.useEffect(() => {
          if (element.current && typeof props.style == "string") {
              element.current.setAttribute("style", props.style);
          }
      }, [props.style]);
      React.useEffect(() => {
          if (element.current && typeof props.name == "string") {
              element.current.setAttribute("name", props.name);
          }
          else if (element.current && props.name == null) {
              element.current.removeAttribute("name");
          }
      }, [props.name]);
      React.useEffect(() => {
          if (element.current && Array.isArray(props.validationList)) {
              element.current.validation.list = props.validationList;
          }
      }, [props.validationList]);
      return (React.createElement("jb-switch", { class: props.className ? props.className : "", "true-title": props.trueTitle ? props.trueTitle : '', "false-title": props.falseTitle ? props.falseTitle : '', ref: element }));
  });
  JBSwitch.displayName = "JBSwitch";

  exports.JBSwitch = JBSwitch;

}));
//# sourceMappingURL=JBSwitch.umd.js.map
